<?php
namespace PanoramaViewer\Site\BlockLayout;

use Omeka\Api\Representation\SiteRepresentation;
use Omeka\Api\Representation\SitePageRepresentation;
use Omeka\Api\Representation\SitePageBlockRepresentation;
use Omeka\Site\BlockLayout\AbstractBlockLayout;
use Laminas\View\Renderer\PhpRenderer;

use Laminas\Form\FormElementManager;

use PanoramaViewer\Form\PanoramaViewerBlockForm;

class PanoramaViewer extends AbstractBlockLayout
{
	/**
     * @var FormElementManager
     */
    protected $formElementManager;

    /**
     * @var array
     */
	protected $defaultSettings = [];

    /**
     * @param FormElementManager $formElementManager
     * @param array $defaultSettings
     */
    public function __construct(FormElementManager $formElementManager, array $defaultSettings)
    {
        $this->formElementManager = $formElementManager;
        $this->defaultSettings = $defaultSettings;
    }

	public function getLabel() {
		return 'Panorama Viewer';
	}

	public function form(PhpRenderer $view,
                       SiteRepresentation $site,
                       SitePageRepresentation $page = null,
                       SitePageBlockRepresentation $block = null
    ) {
		$form = $this->formElementManager->get(PanoramaViewerBlockForm::class);
		$data = $block
			? $block->data() + $this->defaultSettings
			: $this->defaultSettings;
		$form->setData([
			'o:block[__blockIndex__][o:data][panorama_type]' => $data['panorama_type'],
			'o:block[__blockIndex__][o:data][title]' => $data['title'],
			'o:block[__blockIndex__][o:data][width]' => $data['width'],
			'o:block[__blockIndex__][o:data][ratio]' => $data['ratio'],
			'o:block[__blockIndex__][o:data][autoLoad]' => $data['autoLoad'],
		]);
		$form->prepare();

		$html = '';
		$html .= $view->blockAttachmentsForm($block);
		$html .= '<a href="#" class="collapse" aria-label="collapse"><h4>' . $view->translate('Options'). '</h4></a>';
		$html .= '<div class="collapsible" style="padding-top:6px;">';
		$html .= $view->formCollection($form);
        $html .= '</div>';
		return $html;
    }

	public function render(PhpRenderer $view, SitePageBlockRepresentation $block)
	{
		$attachments = $block->attachments();
        if (!$attachments) {
            return '';
		}

		$urls = [];
		static $id = 0;

		foreach ($attachments as $attachment)
		{
			foreach($attachment->item()->media() as $media)
			{
				$mediaType = $media->mediaType();
				$mediaRenderer = $media->renderer();
				if (strpos($mediaType, 'image/') !== false) {
					array_push($urls, $media->originalUrl());
				}
			}
		}
    $width = $block->dataValue('width');
    $height = $width / $block->dataValue('ratio');
		return $view->partial('common/block-layout/panorama-viewer', [
			'panorama_type' => $block->dataValue('panorama_type'),
			'title' => $block->dataValue('title'),
			'width' => $width,
			'height' => $height,
      'autoLoad' => $block->dataValue('autoLoad'),
			'urls' => $urls,
      'id' => 'pv-' . ++$id,
		]);
	}
}
